# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .generation_request import GenerationRequest
from .output_format import OutputFormat


class BytesGenerationRequest(GenerationRequest):
    """
    Examples
    --------
    {"transcript": "Hello, World!", "voice": {"id": "samantha"}}
    """

    output_format: typing.Optional[OutputFormat] = pydantic.Field(default=None)
    """
    Audio format specification.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
