# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class DoneParams(typing_extensions.TypedDict):
    context_id: str
    """
    ID of the context that has finished generating audio.
    """
