# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class CancellationRequestParams(typing_extensions.TypedDict):
    context_id: str
    """
    Use different context IDs for different generations over one WebSocket connection.
    """

    cancel: typing.Literal[True]
