# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SamplingParamsParams(typing_extensions.TypedDict):
    seed: typing_extensions.NotRequired[int]
    """
    Generations with the same parameters _including_ a non-null `seed` are identical.
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Smaller values correspond to more stable but less expressive speech. Must be greater than or equal to 0.
    """

    top_k: typing_extensions.NotRequired[int]
    """
    Must be -1 or greater than 0.
    """

    top_p: typing_extensions.NotRequired[float]
    """
    Must be greater than 0 and less than or equal to 1.
    """

    min_p: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 1, inclusive.
    """

    presence_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 2, inclusive.
    """

    repetition_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 1 and 2, inclusive.
    """

    frequency_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 2, inclusive.
    """
