# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .generation_request import GenerationRequestParams
from .streaming_output_format import StreamingOutputFormatParams


class StreamingGenerationRequestParams(GenerationRequestParams):
    output_format: typing_extensions.NotRequired[StreamingOutputFormatParams]
    """
    Audio format specification.
    """
