# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .voice import VoiceParams


class GenerationRequestParams(typing_extensions.TypedDict):
    transcript: str
    """
    Text for narration.
    """

    voice: VoiceParams
    """
    Voice for narration.
    """
